# gfra [![image](https://img.shields.io/pypi/v/gfra.svg)](https://python.org/pypi/gfra) [![image](https://img.shields.io/pypi/l/gfra.svg)](https://python.org/pypi/gfra) [![image](https://img.shields.io/pypi/pyversions/gfra.svg)](https://python.org/pypi/gfra)

> REST API framework for Google Serverless Functions 

## Description

**gfra** stands for **G**oogle **F**unctions **R**EST **A**PI

## Usage

We use [poetry](https://github.com/sdispater/poetry) for dependency management and publishing.


### Installation
```
$ poetry add gcloud-functions-rest-api
```

### Development

```
WIP
```

### Production
```
WIP
```

### Testing
```
WIP
```

## Documentation
WIP

## Contributions

Feel free to send some [pull request](https://github.com/Tasyp/gfra/pulls) or [issue](https://github.com/Tasyp/gfra/issues).

## License
MIT license

© 2018 [German Ivanov](https://github.com/Tasyp)